package com.company.ftsproblem.web.screens.menu;

import com.haulmont.addon.search.gui.components.RichSearch;
import com.haulmont.cuba.core.global.DataManager;
import com.haulmont.cuba.core.global.UserSessionSource;
import com.haulmont.cuba.gui.Dialogs;
import com.haulmont.cuba.gui.Notifications;
import com.haulmont.cuba.gui.ScreenBuilders;
import com.haulmont.cuba.gui.Screens;
import com.haulmont.cuba.gui.components.*;
import com.haulmont.cuba.gui.components.mainwindow.FoldersPane;
import com.haulmont.cuba.gui.components.mainwindow.SideMenu;
import com.haulmont.cuba.gui.screen.MessageBundle;
import com.haulmont.cuba.gui.screen.Subscribe;
import com.haulmont.cuba.gui.screen.UiController;
import com.haulmont.cuba.gui.screen.UiDescriptor;
import com.haulmont.cuba.security.global.UserSession;
import com.haulmont.cuba.web.App;
import com.haulmont.cuba.web.app.main.MainScreen;

import javax.annotation.Nullable;
import javax.inject.Inject;


@UiController("extMainScreen")
@UiDescriptor("ext-main-side-screen.xml")
public class ExtMainSideScreen extends MainScreen implements Window.HasFoldersPane{
    @Inject
    private Image avatarImage;
    @Inject
    protected SideMenu sideMenu;
    @Inject
    protected Timer updateCountersTimer;
    @Inject
    private UserSession userSession;
    @Inject
    private Label<String> userLabel;
    @Inject
    private Label<String> personLabel;
    @Inject
    private VBoxLayout personalInfoVbox;
    @Inject
    private Label<String> personCompactLabel;
    @Inject
    private FoldersPane foldersPane;
    @Inject
    protected ScrollBoxLayout foldersPanelScrollBox;
    @Inject
    protected Button foldersPaneShowButton;
    @Inject
    private UserSessionSource userSessionSource;
    @Inject
    private HBoxLayout rightButtons;
    @Inject
    protected Screens screens;
    @Inject
    protected ScreenBuilders screenBuilders;
    @Inject
    protected Notifications notifications;
    @Inject
    protected MessageBundle messageBundle;
    @Inject
    protected Dialogs dialogs;
    @Inject
    protected DataManager dataManager;

    @Subscribe
    public void onInit(InitEvent event) {

        boolean menuCollapsedCookie = Boolean.parseBoolean(App.getInstance()
                .getCookieValue(SIDEMENU_COLLAPSED_STATE));

        setCollapsed(isMobileDevice() || menuCollapsedCookie);
        hideSearch(isMobileDevice() || menuCollapsedCookie);

        avatarImage.setStyleName("avatar-icon-small");
        userLabel.setValue(userSession.getCurrentOrSubstitutedUser().getLogin());

        String dashboardCode = userSessionSource.getUserSession().getAttribute("dashboard");
        if (dashboardCode == null || dashboardCode.isEmpty()) {
            dashboardCode = "home";
        }

    }

    @Subscribe("foldersPaneButton")
    protected void onFoldersPaneButtonClick(Button.ClickEvent event) {
        foldersPanelScrollBox.addStyleName("collapsed");
        foldersPaneShowButton.setVisible(true);
    }

    @Subscribe("foldersPaneShowButton")
    protected void onFoldersPaneShowButtonClick(Button.ClickEvent event) {
        foldersPanelScrollBox.removeStyleName("collapsed");
        foldersPaneShowButton.setVisible(false);
    }


    @Subscribe
    protected void onBeforeShow(BeforeShowEvent event) {
        foldersPanelScrollBox.addStyleName("collapsed");
        foldersPaneShowButton.setVisible(true);
    }

    protected void hideSearch(boolean hide) {
        RichSearch searchComponent = (RichSearch) rightButtons.getComponent("search");
        searchComponent.focus();
        searchComponent.setVisible(!hide);
    }
    
    protected void setCollapsed(boolean collapse) {
        if (collapse) {
            personalInfoVbox.addStyleName("collapsed");
        } else {
            personalInfoVbox.removeStyleName("collapsed");
        }
    }

    @Subscribe("collapseMenuButton")
    public void onCollapseMenuButtonClick(Button.ClickEvent event) {
        String menuCollapsedCookie = App.getInstance()
                .getCookieValue(SIDEMENU_COLLAPSED_STATE);

        boolean menuCollapsed = !Boolean.parseBoolean(menuCollapsedCookie);
        setCollapsed(menuCollapsed);
    }

    @Subscribe("searchAction")
    public void onSearchAction(Action.ActionPerformedEvent event) {
        RichSearch searchComponent = (RichSearch) rightButtons.getComponent("search");
        searchComponent.focus();
    }



    @Nullable
    @Override
    public FoldersPane getFoldersPane() {
        return foldersPane;
    }

}