package com.company.ftsproblem.web.screens.person;

import com.haulmont.cuba.core.entity.FileDescriptor;
import com.haulmont.cuba.gui.UiComponents;
import com.haulmont.cuba.gui.components.*;
import com.haulmont.cuba.gui.screen.*;
import com.company.ftsproblem.entity.Person;
import com.haulmont.cuba.gui.screen.LookupComponent;
import de.diedavids.cuba.attachable.web.WithAttachmentsSupport;

import javax.inject.Inject;

@UiController("ftsproblem_Person.browse")
@UiDescriptor("person-browse.xml")
@LookupComponent("personsTable")
@LoadDataBeforeShow
public class PersonBrowse extends StandardLookup<Person> implements WithAttachmentsSupport {

    @Inject
    protected UiComponents uiComponents;
    @Inject
    protected GroupTable<Person> personsTable;
    @Inject
    protected ButtonsPanel buttonsPanel;

    @Subscribe
    public void onInit(InitEvent event) {
        personsTable.addGeneratedColumn("imageFile", this::renderAvatarImageComponent);
    }

    private Component renderAvatarImageComponent(Person person) {
        if (person.getImageFile() == null) {
            return null;
        }
        FileDescriptor imageFile = person.getImageFile();
        if (imageFile == null) {
            return null;
        }
        Image image = smallAvatarImage();
        image.setSource(FileDescriptorResource.class)
                .setFileDescriptor(imageFile);

        return image;
    }

    private Image smallAvatarImage() {
        Image image = uiComponents.create(Image.class);
        image.setScaleMode(Image.ScaleMode.CONTAIN);
        image.setHeight("50");
        image.setWidth("50");
        image.setStyleName("avatar-icon-small");
        return image;
    }

    @Override
    public ListComponent getListComponentForAttachments() {
        return personsTable;
    }

    @Override
    public ButtonsPanel getButtonsPanelForAttachments() {
        return buttonsPanel;
    }
}